document.addEventListener('DOMContentLoaded', () => {
  const canvas = document.getElementById('graphCanvas');
  const ctx = canvas.getContext('2d');
  
  // Set canvas size
  function resizeCanvas() {
    canvas.width = canvas.offsetWidth;
    canvas.height = canvas.offsetHeight;
  }
  
  resizeCanvas();
  window.addEventListener('resize', resizeCanvas);
  
  // Graph data structure
  let nodes = [];
  let edges = [];
  let selectedTool = 'add-node';
  let selectedNode = null;
  
  // Node class
  class Node {
    constructor(x, y) {
      this.x = x;
      this.y = y;
      this.radius = 20;
    }
    
    draw() {
      ctx.beginPath();
      ctx.arc(this.x, this.y, this.radius, 0, Math.PI * 2);
      ctx.fillStyle = '#2a6ee8';
      ctx.fill();
    }
  }
  
  // Edge class
  class Edge {
    constructor(startNode, endNode) {
      this.startNode = startNode;
      this.endNode = endNode;
    }
    
    draw() {
      ctx.beginPath();
      ctx.moveTo(this.startNode.x, this.startNode.y);
      ctx.lineTo(this.endNode.x, this.endNode.y);
      ctx.strokeStyle = '#4b5563';
      ctx.lineWidth = 2;
      ctx.stroke();
    }
  }
  
  // Handle canvas clicks
  canvas.addEventListener('click', (e) => {
    const rect = canvas.getBoundingClientRect();
    const x = e.clientX - rect.left;
    const y = e.clientY - rect.top;
    
    if (selectedTool === 'add-node') {
      nodes.push(new Node(x, y));
      draw();
    }
  });
  
  // Tool selection
  document.querySelectorAll('.tool-btn').forEach(btn => {
    btn.addEventListener('click', () => {
      selectedTool = btn.dataset.tool;
      document.querySelectorAll('.tool-btn').forEach(b => b.classList.remove('active'));
      btn.classList.add('active');
    });
  });
  
  // Draw function
  function draw() {
    ctx.clearRect(0, 0, canvas.width, canvas.height);
    
    edges.forEach(edge => edge.draw());
    nodes.forEach(node => node.draw());
  }
  
  // Animation loop
  function animate() {
    draw();
    requestAnimationFrame(animate);
  }
  
  animate();
});